package # private package
    Test::Text;

1;

=head1 Text - a test library for text output

Ein Absatz im POD.
